Welcome to Savanna!
===================

Savanna project aims to provide users with simple means to provision a Hadoop
cluster at OpenStack by specifying several parameters like Hadoop version,
cluster topology, nodes hardware details and a few more.

Overview
--------

* :doc:`overview`
* :doc:`architecture`
* `Roadmap <https://wiki.openstack.org/wiki/Savanna/Roadmap>`_


User guide
----------
.. toctree::
   :maxdepth: 1

   userdoc/installation.guide
   horizon/installation.guide
   userdoc/overview
   userdoc/features
   userdoc/plugins
   userdoc/registering_image
   userdoc/hadoop-swift
   userdoc/rest_api_v1.0
   userdoc/diskimagebuilder


Developer Guide
---------------
**Programming HowTos and Tutorials**

.. toctree::
    :maxdepth: 1

    devref/development.guidelines
    devref/development.environment
    horizon/dev.environment.guide
    devref/quickstart
    devref/how_to_participate


**Background Concepts for Savanna**

.. toctree::
    :maxdepth: 1

    devref/plugins
    devref/plugin.spi


**Other Resources**

.. toctree::
   :maxdepth: 1

   devref/launchpad
   devref/gerrit
   devref/jenkins

